import { Service, ServicePostOptions } from '../Service';
import { IDResolvable } from '../../Utils/Util';
/**
 * Represents the Radarcord service (formerly Radar Bot Directory).
 * @see https://docs.radarcord.net/
 */
export default class Radarcord extends Service {
    /** The values that can be used to select the service. */
    static get aliases(): string[];
    /** The logo URL. */
    static get logoURL(): string;
    /** Service's name. */
    static get serviceName(): string;
    /** The website URL. */
    static get websiteURL(): string;
    /** The base URL of the service's API. */
    static get baseURL(): string;
    /**
     * Posts statistics to this service.
     * @param options The options of the request
     */
    static post(options: ServicePostOptions): Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * Gets the bot listed on this service.
     * @param id The bot's ID
     */
    getBot(id: IDResolvable): Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * Gets the Unix Epoch Timestamp of the last time this user voted for this bot on this service.
     * @param botID The bot's ID
     * @param userID The user's ID
     */
    getBotVotes(botID: IDResolvable, userID: IDResolvable): Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * Gets the bot's reviews on this service.
     * @param id The bot's ID
     */
    getBotReviews(id: IDResolvable): Promise<import("axios").AxiosResponse<any, any>>;
}
